@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------
 //
-//  Copyright (C) 2008-2018 Fons Adriaensen <fons@linuxaudio.org>
+//  Copyright (C) 2008-2020 Fons Adriaensen <fons@linuxaudio.org>
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -53,14 +53,14 @@ static Mainwin  *mainwin = 0;
 static void help (void)
 {
     fprintf (stderr, "\n%s-%s\n", PROGNAME, VERSION);
-    fprintf (stderr, "(C) 2008-2011 Fons Adriaensen  <fons@linuxaudio.org>\n");
+    fprintf (stderr, "(C) 2008-2020 Fons Adriaensen  <fons@linuxaudio.org>\n");
     fprintf (stderr, "Syntax: jkmeter <options>\n");
     fprintf (stderr, "Options:\n");
     fprintf (stderr, "  -h             Display this text\n");
     fprintf (stderr, "  -name <name>   Jack client name\n");
     fprintf (stderr, "  -s <server>    Jack server name\n");
     fprintf (stderr, "  -g <geometry>  Window position\n");
-    fprintf (stderr, "  -type <type>   Meter type, k20 or k14 (k20)\n");
+    fprintf (stderr, "  -type <type>   Meter type, k20, k14 or k12 (k20)\n");
     fprintf (stderr, "  -rate <rate>   Update rate (30)\n");
     fprintf (stderr, "  -A             Ambisonic (4ch) mode\n");   
     fprintf (stderr, "  -C             Add correlation meter\n");   
