@@ -169,7 +169,6 @@ void Mainwin::redraw (void)
     int     i, x, y;
     XImage  *I = _meters [0]->scale ();
 
-
     if (_vert)
     {
 	x = 8;
@@ -220,13 +219,16 @@ void Mainwin::makegui (void)
     bool        H, V;
     X_hints     xh;
     char        s [1024];
-
+    const char  *t;
+    
     H = _xres->getb (".horizontal", 0);
     V = _xres->getb (".vertical", 0);
     if (! H && ! V) _vert = _xres->get (".orientation", "h")[0] == 'v';  
     else _vert = V;
-    if (strcmp (_xres->get (".type", "k20"), "k14")) _kval = Kmeter::K20;
-    else                                             _kval = Kmeter::K14;
+    _kval = Kmeter::K20;
+    t = _xres->get (".type", "k20");
+    if (!strcmp (t, "k14")) _kval = Kmeter::K14;
+    if (!strcmp (t, "k12")) _kval = Kmeter::K12;
     _chan = _xres->getb (".ambisonic", 0) ? 4 : 2;
     _corr = _xres->getb (".correlation", 0);
 
